@@ -8,6 +8,7 @@
 #define _FCITX5_ZHUYIN_ZHUYINSYMBOL_H_
 
 #include <cstdio>
+#include <istream>
 #include <string>
 #include <unordered_map>
 #include <vector>
@@ -17,8 +18,9 @@ namespace fcitx {
 class ZhuyinSymbol {
 public:
     ZhuyinSymbol();
-    void load(std::FILE *file);
+    void load(std::istream &in);
     const std::vector<std::string> &lookup(const std::string &key) const;
+    void reset();
     void initBuiltin();
     void clear();
 
